public inbox for archer-commits@sourceware.org
help / color / mirror / Atom feed
* [SCM]  archer-ratmice-compile-Wc++-compat: rename all "template" identifiers
@ 2010-09-15 14:34 tromey
  0 siblings, 0 replies; only message in thread
From: tromey @ 2010-09-15 14:34 UTC (permalink / raw)
  To: archer-commits

The branch, archer-ratmice-compile-Wc++-compat has been updated
       via  ccf4e4828b269336f4def4cf6a9f3e4fdad54eb1 (commit)
       via  c1707409ee2ca46c8d42d5c4334dc3fd81e63124 (commit)
      from  658f010598c2c88bf1669aa63d0975107bdb236a (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email.

- Log -----------------------------------------------------------------
commit ccf4e4828b269336f4def4cf6a9f3e4fdad54eb1
Author: Tom Tromey <tromey@redhat.com>
Date:   Wed Sep 15 08:31:43 2010 -0600

    rename all "template" identifiers

commit c1707409ee2ca46c8d42d5c4334dc3fd81e63124
Author: Tom Tromey <tromey@redhat.com>
Date:   Wed Sep 15 08:31:13 2010 -0600

    rename all "typename" identifiers

-----------------------------------------------------------------------

Summary of changes:
 gdb/ada-lang.c    |   12 ++++++------
 gdb/cp-valprint.c |    4 ++--
 gdb/p-valprint.c  |    6 +++---
 gdb/stabsread.c   |    6 +++---
 gdb/typeprint.c   |   12 ++++++------
 5 files changed, 20 insertions(+), 20 deletions(-)

First 500 lines of diff:
diff --git a/gdb/ada-lang.c b/gdb/ada-lang.c
index 74291b4..ba76a71 100644
--- a/gdb/ada-lang.c
+++ b/gdb/ada-lang.c
@@ -6798,17 +6798,17 @@ ada_find_parallel_type_with_name (struct type *type, const char *name)
 struct type *
 ada_find_parallel_type (struct type *type, const char *suffix)
 {
-  char *name, *typename = ada_type_name (type);
+  char *name, *type_name = ada_type_name (type);
   int len;
 
-  if (typename == NULL)
+  if (type_name == NULL)
     return NULL;
 
-  len = strlen (typename);
+  len = strlen (type_name);
 
   name = (char *) alloca (len + strlen (suffix) + 1);
 
-  strcpy (name, typename);
+  strcpy (name, type_name);
   strcpy (name + len, suffix);
 
   return ada_find_parallel_type_with_name (type, name);
@@ -6871,9 +6871,9 @@ variant_field_index (struct type *type)
 /* A record type with no fields.  */
 
 static struct type *
-empty_record (struct type *template)
+empty_record (struct type *template_type)
 {
-  struct type *type = alloc_type_copy (template);
+  struct type *type = alloc_type_copy (template_type);
 
   TYPE_CODE (type) = TYPE_CODE_STRUCT;
   TYPE_NFIELDS (type) = 0;
diff --git a/gdb/cp-valprint.c b/gdb/cp-valprint.c
index 523902f..5ff1e1c 100644
--- a/gdb/cp-valprint.c
+++ b/gdb/cp-valprint.c
@@ -93,9 +93,9 @@ const char vtbl_ptr_name[] = "__vtbl_ptr_type";
 int
 cp_is_vtbl_ptr_type (struct type *type)
 {
-  char *typename = type_name_no_tag (type);
+  char *type_name = type_name_no_tag (type);
 
-  return (typename != NULL && !strcmp (typename, vtbl_ptr_name));
+  return (type_name != NULL && !strcmp (type_name, vtbl_ptr_name));
 }
 
 /* Return truth value for the assertion that TYPE is of the type
diff --git a/gdb/p-valprint.c b/gdb/p-valprint.c
index d659367..ddf8254 100644
--- a/gdb/p-valprint.c
+++ b/gdb/p-valprint.c
@@ -625,10 +625,10 @@ const char pascal_vtbl_ptr_name[] =
 int
 pascal_object_is_vtbl_ptr_type (struct type *type)
 {
-  char *typename = type_name_no_tag (type);
+  char *type_name = type_name_no_tag (type);
 
-  return (typename != NULL
-	  && strcmp (typename, pascal_vtbl_ptr_name) == 0);
+  return (type_name != NULL
+	  && strcmp (type_name, pascal_vtbl_ptr_name) == 0);
 }
 
 /* Return truth value for the assertion that TYPE is of the type
diff --git a/gdb/stabsread.c b/gdb/stabsread.c
index f6b096c..09290c1 100644
--- a/gdb/stabsread.c
+++ b/gdb/stabsread.c
@@ -4525,9 +4525,9 @@ cleanup_undefined_types_1 (void)
 		struct pending *ppt;
 		int i;
 		/* Name of the type, without "struct" or "union" */
-		char *typename = TYPE_TAG_NAME (*type);
+		char *type_name = TYPE_TAG_NAME (*type);
 
-		if (typename == NULL)
+		if (type_name == NULL)
 		  {
 		    complaint (&symfile_complaints, _("need a type name"));
 		    break;
@@ -4545,7 +4545,7 @@ cleanup_undefined_types_1 (void)
 			    && (TYPE_INSTANCE_FLAGS (*type) ==
 				TYPE_INSTANCE_FLAGS (SYMBOL_TYPE (sym)))
 			    && strcmp (SYMBOL_LINKAGE_NAME (sym),
-				       typename) == 0)
+				       type_name) == 0)
                           replace_type (*type, SYMBOL_TYPE (sym));
 		      }
 		  }
diff --git a/gdb/typeprint.c b/gdb/typeprint.c
index ce9f551..a645f5a 100644
--- a/gdb/typeprint.c
+++ b/gdb/typeprint.c
@@ -181,12 +181,12 @@ whatis_command (char *exp, int from_tty)
   whatis_exp (exp, -1);
 }
 
 /* TYPENAME is either the name of a type, or an expression.  */
 
 static void
-ptype_command (char *typename, int from_tty)
+ptype_command (char *type_name, int from_tty)
 {
-  whatis_exp (typename, 1);
+  whatis_exp (type_name, 1);
 }
 
 /* Print integral scalar data VAL, of type TYPE, onto stdio stream STREAM.
@@ -277,16 +277,16 @@ print_type_scalar (struct type *type, LONGEST val, struct ui_file *stream)
    and whatis_command().  */
 
 void
-maintenance_print_type (char *typename, int from_tty)
+maintenance_print_type (char *type_name, int from_tty)
 {
   struct value *val;
   struct type *type;
   struct cleanup *old_chain;
   struct expression *expr;
 
-  if (typename != NULL)
+  if (type_name != NULL)
     {
-      expr = parse_expression (typename);
+      expr = parse_expression (type_name);
       old_chain = make_cleanup (free_current_contents, &expr);
       if (expr->elts[0].opcode == OP_TYPE)
 	{
@@ -181,12 +181,12 @@ whatis_command (char *exp, int from_tty)
 }
 
-/* TYPENAME is either the name of a type, or an expression.  */
+/* TYPE_NAME is either the name of a type, or an expression.  */
 
 static void


hooks/post-receive
--
Repository for Project Archer.


^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2010-09-15 14:34 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2010-09-15 14:34 [SCM] archer-ratmice-compile-Wc++-compat: rename all "template" identifiers tromey

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).